@@ -114,7 +114,8 @@ class EsOp():
             return '未查到'
 
     def index_search(self,index_name,body):
-        self.conn.search(index=index_name,body=body)
+        result =  self.conn.search(index=index_name,body=body)
+        return self.index_result_dict(result)
     def index_search_all(self,index_name,pn=1,size=10000,doc_type=''):
         body = {
             "query": {
